@@ -7,7 +7,7 @@ from typing import Any, Callable, Dict, List, Optional, Sequence, Tuple, Union
 import numpy as np
 import torch
 
-from ai_traineree.types import ActionType, MultiAgentTaskType, StateType, TaskType
+from ai_traineree.types import ActionType, DataSpace, MultiAgentTaskType, StateType, TaskType
 
 try:
     import gym
@@ -102,6 +102,14 @@ class GymTask(TaskType):
         else:
             return sum(action_space.shape)
 
+    @property
+    def obs_space(self) -> DataSpace:
+        return DataSpace.from_gym_space(self.env.observation_space)
+
+    @property
+    def action_space(self) -> DataSpace:
+        return DataSpace.from_gym_space(self.env.action_space)
+
     @property
     def actual_obs_size(self) -> int:
         return reduce(mul, self.reset().shape)
@@ -179,6 +187,14 @@ class PettingZooTask(MultiAgentTaskType):
         self.name = "CUSTOM"
         self.agent_iter = self.env.agent_iter
 
+    @property
+    def obs_space(self):
+        return {unit: DataSpace.from_gym_space(space) for (unit, space) in self.env.observation_spaces.items()}
+
+    @property
+    def action_space(self):
+        return {unit: DataSpace.from_gym_space(space) for (unit, space) in self.env.action_spaces.items()}
+
     @property
     def obs_size(self):
         return self.env.observe(self.env.agents[0]).shape
