@@ -1,5 +1,3 @@
-# TODO: Check that it works
-
 from ai_traineree.agents.dqn import DQNAgent
 from ai_traineree.env_runner import EnvRunner
 from ai_traineree.tasks import GymTask
@@ -14,11 +12,11 @@ config = {
     "device": "cuda",
 }
 task = GymTask(env_name)
-agent = DQNAgent(task.obs_size, task.action_size, **config)
+agent = DQNAgent(task.obs_space, task.action_space, **config)
 env_runner = EnvRunner(task, agent)
 
 # env_runner.interact_episode(0, render=True)
-scores = env_runner.run(reward_goal=5, max_episodes=5000, log_every=1)
+scores = env_runner.run(reward_goal=5, max_episodes=5000)
 env_runner.interact_episode(100, render=True)
 
 # plot the scores
