@@ -16,10 +16,10 @@ env_name = 'CartPole-v1'
 task = GymTask(env_name)
 data_logger = TensorboardLogger()
 
-agent = Agent(task.obs_size, task.action_size, device='cpu')
+agent = Agent(task.obs_space, task.action_space, device='cpu')
 env_runner = EnvRunner(task, agent, data_logger=data_logger)
 
-scores = env_runner.run(reward_goal=100, max_episodes=500, eps_decay=0.9, force_new=True)
+scores = env_runner.run(reward_goal=100, max_episodes=500, eps_decay=0.98, force_new=True)
 env_runner.interact_episode(render=True)
 data_logger.close()
 
